@@ -4,12 +4,42 @@ from getpass import getpass
 from bcrypt import hashpw, gensalt
 import pyonr
 
-v = '1.0.0b1'
+def read(rel_path):
+   import codecs
+   here = os.path.abspath(os.path.dirname(__file__))
+   with codecs.open(os.path.join(here, rel_path), 'r') as fp:
+      return fp.read()
+
+def get_version(rel_path):
+   for line in read(rel_path).splitlines():
+      if line.startswith('__version__'):
+         delim = '"' if '"' in line else "'"
+         return line.split(delim)[1]
+   else:
+      raise RuntimeError("Unable to find version string.")
+
+v = get_version('__init__.py')
 
 def get_password():   
    password = hashpw(getpass('Password: ').encode('utf-8'), gensalt())
    return password
 
+def create_db(name, _password=None):
+   schema = {
+      '__docs': []
+   }
+
+   with open(name, 'w') as file:
+         if not _password:
+            file.write(pyonr.dumps(schema))
+         else:
+            try:
+               password = get_password()
+               schema['__password'] = password
+            except KeyboardInterrupt:
+               pass
+            file.write(pyonr.dumps(schema))
+
 def main():
    pass
 
@@ -24,9 +54,6 @@ args = parser.parse_args()
 if len(args.filename) != 0:
    filename = args.filename[0]
    ispassword = args.password
-   schema = {
-      '__docs': []
-   }
 
    if os.path.isfile(filename) or os.path.isfile(f'{filename}.ndb'):
       parser.error(f'{filename}: already exists')
@@ -34,13 +61,4 @@ if len(args.filename) != 0:
       if not filename.endswith('.ndb'):
          filename += '.ndb'
 
-      with open(filename, 'w') as file:
-         if not ispassword:
-            file.write(pyonr.dumps(schema))
-         else:
-            try:
-               password = get_password()
-               schema['__password'] = password
-            except KeyboardInterrupt:
-               pass
-            file.write(pyonr.dumps(schema))
\ No newline at end of file
+      create_db(filename, ispassword)
\ No newline at end of file
